@@ -6,5 +6,4 @@ set -v
 
 python3 ./setupsrc/pl_setup/build_pdfium.py
 export PYP_TARGET_PLATFORM="sourcebuild"
-bash ./utilities/install.sh
-#python3 -m build -n -x --wheel
+python3 -m pip install . -v --no-build-isolation
