@@ -12,13 +12,18 @@ whl_targets=(
     "linux_arm32"
     "linux_x64"
     "linux_x86"
+    "musllinux_x64"
+    "musllinux_x86"
     "windows_arm64"
     "windows_x64"
     "windows_x86"
 )
 for target in ${whl_targets[*]}; do
     echo "$target"
+    rm -rf build/
     PYP_TARGET_PLATFORM="$target" python3 -m build -n -x --wheel
+    rm -rf build/
+    pushd src/pypdfium2/; rm -f _pypdfium.py pdfium pdfium.dll pdfium.dylib; popd
 done
 
 # package source distribution
